@@ -9,7 +9,7 @@ from sklearn.preprocessing import OneHotEncoder
 
 # lib utils
 from xgbse._base import XGBSEBaseEstimator, DummyLogisticRegression
-from xgbse.converters import convert_data_to_xgb_format, convert_y
+from xgbse.converters import convert_data_to_xgb_format, convert_y, hazard_to_survival
 
 # at which percentiles will the KM predict
 from xgbse.non_parametric import get_time_bins, calculate_interval_failures
@@ -229,7 +229,7 @@ class XGBSEDebiasedBCE(XGBSEBaseEstimator):
         # predicting and encoding leaves
         self.encoder = OneHotEncoder()
         leaves = self.bst.predict(
-            dtrain, pred_leaf=True, ntree_limit=self.bst.best_ntree_limit
+            dtrain, pred_leaf=True, iteration_range=(0, self.bst.best_iteration + 1)
         )
         leaves_encoded = self.encoder.fit_transform(leaves)
 
@@ -247,7 +247,7 @@ class XGBSEDebiasedBCE(XGBSEBaseEstimator):
                 index_id = X.index.copy()
 
             index_leaves = self.bst.predict(
-                dtrain, pred_leaf=True, ntree_limit=self.bst.best_ntree_limit
+                dtrain, pred_leaf=True, iteration_range=(0, self.bst.best_iteration + 1)
             )
             self.tree = BallTree(index_leaves, metric="hamming")
 
@@ -346,9 +346,7 @@ class XGBSEDebiasedBCE(XGBSEBaseEstimator):
 
         # converting these interval predictions
         # to cumulative survival curve
-        preds = (1 - preds).cumprod(axis=1)
-
-        return preds
+        return hazard_to_survival(preds)
 
     def predict(self, X, return_interval_probs=False):
         """
@@ -374,7 +372,7 @@ class XGBSEDebiasedBCE(XGBSEBaseEstimator):
 
         # getting leaves and extracting neighbors
         leaves = self.bst.predict(
-            d_matrix, pred_leaf=True, ntree_limit=self.bst.best_ntree_limit
+            d_matrix, pred_leaf=True, iteration_range=(0, self.bst.best_iteration + 1)
         )
         leaves_encoded = self.encoder.transform(leaves)
 
